@@ -82,17 +82,19 @@ def get_person(link):
             date = f.get_dig_date("01 01 1901")
         if date == -1:
             date = f.get_dig_date("01 01 1901")
+        if type(date) != type({}):
+            date = f.get_dig_date("01 01 1901")
         return {
-                        'image_link': image_link,
-                        'first_name': name[1],
-                        'middle_name': name[2],
-                        'last_name': name[0],
-                        'link': link,
-                        'bday': date['day'],
-                        'bmonth': date['month'],
-                        'byear': date['year'],
-                        'position_id': 26
-                }
+            'image_link': image_link,
+            'first_name': name[1],
+            'middle_name': name[2],
+            'last_name': name[0],
+            'link': link,
+            'bday': date['day'],
+            'bmonth': date['month'],
+            'byear': date['year'],
+            'position_id': 26
+        }
     else:
         return 1
 
@@ -133,4 +135,4 @@ def parser():
     else:
         return [{'code': 2, 'script': os.path.basename(__file__)}]
     log.debug("The script stops working")
-    return people
+    return people
\ No newline at end of file
