@@ -90,14 +90,22 @@ def parser_people_links(link):
         html = f.get_html(link+addition+addition_kr)
     else:
         html = f.get_html(link+addition)
+    if html.status_code == 503:
+        log.warning("Server offline, skipping")
+        return None
     soup = BeautifulSoup(html.text, 'html.parser')
     soup = soup.find('div', class_='l-columns')
     if soup != None:
         soup = soup.find('div', class_='l-column l-column--left js-column')
         try:
             soup1 = soup.find('ul', class_='b-menu js-menu menu')
-            soup1 = soup1.find('li', class_='b-menu-item js-menu-item b-menu-item--active js-menu-item--active b-menu-item--is_submenu')
-            soup1 = soup1.find('div', class_='b-submenu js-submenu b-submenu--all')
+            soup4 = soup1.find('li', class_='b-menu-item--active')
+            try:
+                soup4 = soup4.find('div', class_='b-submenu js-submenu b-submenu--all')
+                soup1 = soup4
+            except:
+                soup1 = soup1.find("div", class_="b-menu-item js-menu-item b-menu-item--active js-menu-item--active b-menu-item--is_submenu")
+                soup1 = soup1.find('div', class_='b-submenu js-submenu b-submenu--all')
             soup1 = soup1.find('ul', class_='b-menu js-menu menu')
             soup1 = soup1.find_all('li')
         except:
@@ -257,25 +265,29 @@ def parser():
                     people.append(person)
         people.extend(get_orenburg())
 
+
         html_tver = f.get_html("https://tver.arbitr.ru/node/3515")
         soup_tver = BeautifulSoup(html_tver.text, "html.parser")
         soup_tver = soup_tver.find("div", class_="node")
         tver_list = soup_tver.find_all("p")
         tver_list = tver_list[1:]
         for item in tver_list:
-            name = item.find("strong").get_text().replace("\n", "")
-            name = f.get_name(name)
-            people.append({
-                'image_link': "-",
-                'first_name': name[1],
-                'middle_name': name[2],
-                'last_name': name[0],
-                'link': "https://tver.arbitr.ru/node/3515",
-                'bday': 1,
-                'bmonth': 1,
-                'byear': 1901,
-                'position_id': 44,
-            })
+            try:
+                name = item.find("strong").get_text().replace("\n", "")
+                name = f.get_name(name)
+                people.append({
+                    'image_link': "-",
+                    'first_name': name[1],
+                    'middle_name': name[2],
+                    'last_name': name[0],
+                    'link': "https://tver.arbitr.ru/node/3515",
+                    'bday': 1,
+                    'bmonth': 1,
+                    'byear': 1901,
+                    'position_id': 44,
+                })
+            except:
+                pass
 
         html_fasvso = f.get_html("http://fasvso.arbitr.ru/about/struktura_suda/svedeniya_o_sud_yah/")
         soup_fasvso = BeautifulSoup(html_fasvso.text, "html.parser")
